@@ -3,7 +3,7 @@ library(treeman)
 library(testthat)
 
 # DATA
-tree <- randTree(100)
+tree <- randTree(100, wndmtrx=sample(c(TRUE, FALSE), 1))
 
 # RUNNING
 context('Testing \'TreeMan Class\'')
@@ -20,7 +20,8 @@ test_that('[[ works', {
 })
 test_that('[ works', {
   expect_error(tree['not a valid slot name'])
+  expect_type(tree['age'], 'double')
+  expect_type(tree['ultr'], 'logical')
   expect_that(tree['ntips'], equals(100))
   expect_that(tree['nnds'], equals(99))
-  expect_that(tree['age'], equals(tree@age))
 })
\ No newline at end of file
